import os


def make_mk_weekly_path(mata_kuliah: str, semester: int, n_weeks: int = 16):
    current_path = os.getcwd()
    path = os.path.join(current_path, f"semester {semester}")
    os.mkdir(path)
    mata_kuliahs = mata_kuliah.split(",")

    current_path = path
    for mata_kuliah in mata_kuliahs:
        path = os.path.join(current_path, mata_kuliah)
        os.mkdir(path)

        current_current_path = path
        for week in range(n_weeks):
            content = f"week {week + 1}"
            path_path = os.path.join(current_current_path, content)
            os.mkdir(path_path)



import os


def make_ds2_ml2_path():
    dirs = ["data", "notebooks", "src"]
    current_path = os.getcwd()

    for idx, dir in enumerate(dirs):
        path = os.path.join(current_path, dir)
        os.mkdir(path)
        if idx == 0:
            data_path = ["raw", "processed"]
            current_current_path = path
            for data_dir in data_path:
                path_path = os.path.join(current_current_path, data_dir)
                os.mkdir(path_path)

        if idx == 1:
            notebook_path = ["exploration", "modeling"]
            current_current_path = path
            for notebook_dir in notebook_path:
                path_path = os.path.join(current_current_path, notebook_dir)
                os.mkdir(path_path)
                f = open(os.path.join(path_path, ".keep"), "x")

        if idx == 2:
            files = ["train.py", "dataset.py"]
            folders = ["tuned_hyperparameters", "models"]
            current_current_path = path

            for folder in folders:
                src_path = os.path.join(current_current_path, folder)
                os.mkdir(src_path)

            for file in files:
                f = open(os.path.join(current_current_path, file), "x")
                f.close()

    other_files = ["README.md", "LICENSE", "requirements.txt", ".gitignore"]
    for file in other_files:
        f = open(os.path.join(current_path, file), "x")
        f.close()



import sys
from .semester import make_semester_path
from .ds_ml import make_ds_ml_path
from .ds2 import make_ds2_ml2_path
from .semester_week import make_mk_weekly_path


def mkfol():
    if len(sys.argv) <= 1:
        print("Usage: mkfol -h")
        return

    if sys.argv[1] == "-h" or sys.argv[1] == "--help":
        print(
            """
            misc:
            -h / --help : show this help
            -v / --version : show version

            main feature:
            -s / --semester : make semester folder
            -ds / --datascience / -ml / --machinelearning : make ds_ml folder
            -ds2 / --datascience2 / -ml2 / --machinelearning2 : make ds 2 folder
            -w / --week
            
            usage:
            mkfol -s <semester> <mata kuliah (separate with comma)>
            mkfol -w <semester> <mata kuliah (separate with comma)> <number of weeks>
            """
        )
        return

    if sys.argv[1] == "-v" or sys.argv[1] == "--version":
        print("mkfol version 1.0")
        return

    if sys.argv[1] == "-s" or sys.argv[1] == "--semester":
        semester = int(sys.argv[2])
        mata_kuliah = sys.argv[3]
        make_semester_path(mata_kuliah, semester)
        print("semester folder created")
        return

    if sys.argv[1] == "-ds" or sys.argv[1] == "--datascience" or sys.argv[1] == "-ml" or sys.argv[1] == "--machinelearning":
        make_ds_ml_path()
        print("data science or machine learning project folder created")
        return

    if sys.argv[1] == "-ds2" or sys.argv[1] == "--datascience2" or sys.argv[1] == "-ml2" or sys.argv[1] == "--machinelearning2":
        make_ds2_ml2_path()
        print("data science 2 or machine learning 2 project folder created")

    if sys.argv[1] == "-w" or sys.argv[1] == "--week":
        semester = int(sys.argv[2])
        mata_kuliah = sys.argv[3]
        week = int(sys.argv[4])
        make_mk_weekly_path(mata_kuliah, semester, week)

    else:
        print("Please enter valid arguments! mkfol -h for help")


if __name__ == "__main__":
    mkfol()
